Module: SolidusMollie::Spree::CheckoutControllerDecorator
- Defined in:
- app/decorators/solidus_mollie/spree/checkout_controller_decorator.rb
Overview
Intercepts the checkout confirm step. When the order is paying with a Mollie payment method, the buyer is redirected to Mollie’s hosted checkout instead of the order being completed synchronously. The order is finished later by the webhook (see SolidusMollie::ProcessWebhook).
Instance Method Summary collapse
Instance Method Details
#update ⇒ Object
10 11 12 13 14 |
# File 'app/decorators/solidus_mollie/spree/checkout_controller_decorator.rb', line 10 def update return redirect_to_mollie if divert_to_mollie? super end |